@extends('layouts.app')

@section('title', $slide ?? null ? 'Edit Slide' : 'Create Slide')

@section('content')
<div class="container mx-auto p-4">
    <h1 class="text-2xl font-bold mb-4">{{ $slide ?? null ? 'Edit Slide' : 'Create Slide' }}</h1>

    <form action="{{ $slide ?? null ? route('slides.update', $slide) : route('slides.store') }}" method="POST">
        @csrf
        @if($slide ?? null)
            @method('PUT')
        @endif

        <div class="mb-4">
            <label class="block text-gray-700">Group Name</label>
            <input type="text" name="group_name" value="{{ $slide->group_name ?? old('group_name') }}" class="border border-gray-300 rounded w-full py-2 px-4">
            @error('group_name')<p class="text-red-500">{{ $message }}</p>@enderror
        </div>

        <div class="mb-4">
            <label class="block text-gray-700">Heading</label>
            <input type="text" name="heading" value="{{ $slide->heading ?? old('heading') }}" class="border border-gray-300 rounded w-full py-2 px-4">
            @error('heading')<p class="text-red-500">{{ $message }}</p>@enderror
        </div>

        <div id="list-items">
            @foreach ($slide->listItems ?? [] as $index => $item)
                <div class="mb-4 list-item">
                    <label class="block text-gray-700">List Name</label>
                    <input type="text" name="list_items[{{ $index }}][list_name]" value="{{ $item->list_name }}" class="border border-gray-300 rounded w-full py-2 px-4">
                    <label class="block text-gray-700">Domains</label>
                    <input type="text" name="list_items[{{ $index }}][domains]" value="{{ $item->domains }}" class="border border-gray-300 rounded w-full py-2 px-4">
                    <button type="button" class="remove-item bg-red-500 text-white px-4 py-2 rounded mt-2">Remove</button>
                </div>
            @endforeach
        </div>

        <button type="button" id="add-item" class="bg-blue-500 text-white px-4 py-2 rounded mb-4">Add List Item</button>

        <div class="mb-4">
            <button type="submit" class="bg-green-500 text-white px-4 py-2 rounded">Save</button>
        </div>
    </form>
</div>

<script>
    let index = {{ $slide->listItems->count() ?? 0 }};
    
    document.getElementById('add-item').addEventListener('click', function () {
        const listItemContainer = document.createElement('div');
        listItemContainer.classList.add('mb-4', 'list-item');
        listItemContainer.innerHTML = `
            <label class="block text-gray-700">List Name</label>
            <input type="text" name="list_items[${index}][list_name]" class="border border-gray-300 rounded w-full py-2 px-4">
            <label class="block text-gray-700">Domains</label>
            <input type="text" name="list_items[${index}][domains]" class="border border-gray-300 rounded w-full py-2 px-4">
            <button type="button" class="remove-item bg-red-500 text-white px-4 py-2 rounded mt-2">Remove</button>
        `;
        document.getElementById('list-items').appendChild(listItemContainer);
        index++;
    });

    document.getElementById('list-items').addEventListener('click', function (event) {
        if (event.target.classList.contains('remove-item')) {
            event.target.closest('.list-item').remove();
        }
    });
</script>
@endsection
