@extends('layouts.app')

@section('content')
<div class="container mx-auto p-4" x-data="{ openMovePopup: false, selectedListItemId: null }">
    <h1 class="text-2xl font-bold mb-4">Slide Details</h1>

    <!-- Display slide details -->
    <div class="bg-white shadow rounded-lg p-6">
        <div class="mb-4">
            <h2 class="text-xl font-semibold">Group Name:</h2>
            <p>{{ $slide->group_name }}</p>
        </div>

        <div class="mb-4">
            <h2 class="text-xl font-semibold">Heading:</h2>
            <p>{{ $slide->heading }}</p>
        </div>

        <!-- List Items -->
        <div>
            <h2 class="text-xl font-semibold mb-2">List Items:</h2>
            @foreach($slide->listItems as $item)
                <div class="mb-4">
                    <h3 class="text-lg font-semibold">{{ $item->list_name }}</h3>
                    <p>{{ $item->domains }}</p>

                    <!-- Move Button -->
                    <button @click="openMovePopup = true; selectedListItemId = {{ $item->id }}" class="bg-blue-500 text-white px-4 py-2 rounded">
                        Move to Another Slide
                    </button>
                </div>
            @endforeach
        </div>

        <!-- Move to Another Slide Popup -->
        <div x-show="openMovePopup" class="fixed inset-0 flex items-center justify-center z-50 backdrop-blur-sm">
            <div class="bg-white p-4 rounded shadow-lg w-96">
                <h3 class="text-lg font-semibold mb-2">Move List Item to Another Slide</h3>
                <form method="POST" action="{{ route('list-items.move') }}">
                    @csrf
                    <input type="hidden" name="list_item_id" x-bind:value="selectedListItemId">

                    <div class="mb-4">
                        <label for="slide_id" class="block text-gray-700">Select Slide</label>
                        <select name="slide_id" id="slide_id" class="border border-gray-300 rounded w-full py-2 px-4">
                            @foreach($allSlides as $otherSlide)
                                <option value="{{ $otherSlide->id }}">{{ $otherSlide->group_name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="flex justify-end space-x-2">
                        <button type="button" @click="openMovePopup = false" class="bg-gray-500 text-white px-4 py-2 rounded">Cancel</button>
                        <button type="submit" class="bg-green-500 text-white px-4 py-2 rounded">Move</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- Created By and Modified By -->
        <div class="mt-6">
            <h2 class="text-xl font-semibold">Created By:</h2>
            <p>{{ $slide->created_by ? $slide->creator->name : 'N/A' }}</p> 

            <h2 class="text-xl font-semibold mt-4">Last Modified By:</h2>
            <p>{{ $slide->updater ? $slide->updater->name : 'N/A' }}</p>
        </div>
    </div>

    <!-- Back to Index Button -->
    <div class="mt-6">
        <a href="{{ route('slides.index') }}" class="text-blue-500 hover:text-blue-700">
            &larr; Back to Slide List
        </a>
    </div>
</div>
@endsection
