

<?php $__env->startSection('content'); ?>
<div class="p-6 bg-gray-50 min-h-screen">
    <h1 class="text-3xl font-bold text-gray-900 mb-6">Users</h1>

    <!-- Success and Error Messages -->
    <?php if(session('success')): ?>
        <div class="bg-green-100 text-green-800 p-4 mb-4 rounded-lg shadow-md flex items-center">
            <i class="fas fa-check-circle mr-2"></i> <?php echo e(session('success')); ?>

        </div>
    <?php endif; ?>
    <?php if(session('error')): ?>
        <div class="bg-red-100 text-red-800 p-4 mb-4 rounded-lg shadow-md flex items-center">
            <i class="fas fa-exclamation-circle mr-2"></i> <?php echo e(session('error')); ?>

        </div>
    <?php endif; ?>

    <div class="overflow-x-auto">
        <table class="min-w-full bg-white border border-gray-200 rounded-lg shadow-md">
            <thead class="bg-purple-600 text-white">
                <tr>
                    <th class="py-3 px-4 border-b">Name</th>
                    <th class="py-3 px-4 border-b">Email</th>
                    <th class="py-3 px-4 border-b">Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php $__currentLoopData = $users; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $user): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <tr class="hover:bg-gray-50 transition duration-200">
                        <td class="py-3 px-4 border-b text-gray-800"><?php echo e($user->name); ?></td>
                        <td class="py-3 px-4 border-b text-gray-600"><?php echo e($user->email); ?></td>
                        <td class="py-3 px-4 border-b space-x-2 flex">
                            <!-- Change Password Button -->
                            <button onclick="openModal('<?php echo e($user->id); ?>')"
                                    class="bg-purple-500 text-white px-4 py-2 rounded-lg hover:bg-purple-600 focus:outline-none focus:ring-2 focus:ring-purple-500 transition duration-200 flex items-center">
                                <i class="fas fa-key mr-2"></i> Change Password
                            </button>

                            <!-- Delete Button -->
                            <button onclick="confirmDelete('<?php echo e($user->id); ?>')"
                                    class="bg-red-500 text-white px-4 py-2 rounded-lg hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-red-500 transition duration-200 flex items-center">
                                <i class="fas fa-trash-alt mr-2"></i> Delete
                            </button>

                            <form action="<?php echo e(route('users.destroy', $user->id)); ?>" method="POST" id="delete-form-<?php echo e($user->id); ?>" style="display:none;">
                                <?php echo csrf_field(); ?>
                                <?php echo method_field('DELETE'); ?>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
            </tbody>
        </table>
    </div>

    <!-- Change password modal -->
    <div id="change-password-modal" class="fixed inset-0 bg-gray-500 bg-opacity-75 flex items-center justify-center hidden">
        <div class="bg-white p-6 rounded-lg shadow-lg w-full max-w-sm">
            <h2 class="text-xl font-semibold mb-4 text-gray-900">Change Password</h2>
            <form id="change-password-form" method="POST">
                <?php echo csrf_field(); ?>
                <?php echo method_field('PUT'); ?>
                <input type="hidden" name="user_id" id="user-id">
                <div class="mb-4">
                    <label for="password" class="block text-gray-700">New Password</label>
                    <input type="password" name="password" id="password" required class="w-full mt-1 border border-gray-300 rounded-md p-2">
                </div>
                <div class="mb-4">
                    <label for="password_confirmation" class="block text-gray-700">Confirm Password</label>
                    <input type="password" name="password_confirmation" id="password_confirmation" required class="w-full mt-1 border border-gray-300 rounded-md p-2">
                </div>
                <div class="flex justify-end space-x-2">
                    <button type="submit" class="bg-purple-500 text-white px-4 py-2 rounded-lg hover:bg-purple-600 focus:outline-none focus:ring-2 focus:ring-purple-500 transition duration-200 flex items-center">
                        <i class="fas fa-check mr-2"></i> Update Password
                    </button>
                    <button type="button" onclick="closeModal()"
                            class="bg-gray-300 text-gray-800 px-4 py-2 rounded-lg hover:bg-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-300 transition duration-200 flex items-center">
                        <i class="fas fa-times mr-2"></i> Cancel
                    </button>
                </div>
            </form>
        </div>
    </div>

    <!-- Delete confirmation modal -->
    <div id="delete-confirmation-modal" class="fixed inset-0 bg-gray-500 bg-opacity-75 flex items-center justify-center hidden">
        <div class="bg-white p-6 rounded-lg shadow-lg w-full max-w-sm">
            <h2 class="text-xl font-semibold mb-4 text-gray-900">Confirm Deletion</h2>
            <p class="mb-4 text-gray-700">Are you sure you want to delete this user?</p>
            <div class="flex justify-end space-x-2">
                <button id="confirm-delete-button" type="button" class="bg-red-500 text-white px-4 py-2 rounded-lg hover:bg-red-600 focus:outline-none focus:ring-2 focus:ring-red-500 transition duration-200 flex items-center">
                    <i class="fas fa-check mr-2"></i> Delete
                </button>
                <button type="button" onclick="closeDeleteModal()"
                        class="bg-gray-300 text-gray-800 px-4 py-2 rounded-lg hover:bg-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-300 transition duration-200 flex items-center">
                    <i class="fas fa-times mr-2"></i> Cancel
                </button>
            </div>
        </div>
    </div>

    <script>
        let deleteUserId = null;

        function openModal(userId) {
            document.getElementById('change-password-modal').classList.remove('hidden');
            document.getElementById('user-id').value = userId;
            document.getElementById('change-password-form').action = `/users/${userId}/update-password`;
        }

        function closeModal() {
            document.getElementById('change-password-modal').classList.add('hidden');
        }

        function confirmDelete(userId) {
            deleteUserId = userId;
            document.getElementById('delete-confirmation-modal').classList.remove('hidden');
        }

        function closeDeleteModal() {
            document.getElementById('delete-confirmation-modal').classList.add('hidden');
            deleteUserId = null;
        }

        document.getElementById('confirm-delete-button')?.addEventListener('click', function() {
            if (deleteUserId) {
                document.getElementById('delete-form-' + deleteUserId).submit();
            }
            closeDeleteModal();
        });
    </script>
</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH C:\Users\shuvo\Desktop\pbn\pbn_slider\resources\views\users\index.blade.php ENDPATH**/ ?>